aboutsummaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
Diffstat (limited to 'modules')
-rw-r--r--modules/games-config.el16
1 files changed, 11 insertions, 5 deletions
diff --git a/modules/games-config.el b/modules/games-config.el
index 9aa598168..1e5ba5b87 100644
--- a/modules/games-config.el
+++ b/modules/games-config.el
@@ -5,9 +5,9 @@
;;
;; Layer: 4 (Optional).
;; Category: O.
;; Load shape: eager.
;; Eager reason: none; optional games, a command-loaded deferral candidate.
;; Top-level side effects: package configuration via use-package.
;; Runtime requires: none.
;; Direct test load: yes.
;;
@@ -17,20 +17,26 @@
;; (stories directory: ~/sync/org/text.games/)
;; - 2048 number-tile puzzle game
;;
+;; init.el autoloads `malyon' and `2048-game' to this module instead of
+;; requiring it eagerly, so the first invocation of either command loads
+;; games-config, which configures and then loads the package.
+;;
;;; Code:
;; ----------------------------------- Malyon ----------------------------------
;; text based adventure player
(use-package malyon
- :defer 1
+ :defer t
+ :commands (malyon)
:config
(setq malyon-stories-directory (concat org-dir "text.games/")))
;; ------------------------------------ 2048 -----------------------------------
;; combine numbered tiles to create the elusive number 2048.
(use-package 2048-game
- :defer 1)
+ :defer t
+ :commands (2048-game))
(provide 'games-config)
;;; games-config.el ends here.
@@ -5,9 +5,9 @@
;; Layer: 4 (Optional).
;; Category: O.
-;; Load shape: eager.
-;; Eager reason: none; optional games, a command-loaded deferral candidate.
-;; Top-level side effects: package configuration via use-package.
+;; Load shape: command (deferred).
+;; Eager reason: none; loaded on first use of `malyon' or `2048-game'.
+;; Top-level side effects: package configuration via use-package (deferred).
;; Runtime requires: none.
;; Direct test load: yes.